searchData={"content_type":"text/markdown","items":[{"doc":"Phoenix component for rendering SEO-related elements in the HTML head.\n\nThis component renders meta tags, JSON-LD structured data, and link tags\nthat have been generated by the `PhoenixSEOTools.SEO` module.","ref":"PhoenixSEOTools.Components.Head.html","title":"PhoenixSEOTools.Components.Head","type":"module"},{"doc":"Add this component to your root layout:\n\n```heex\n \n   \n   \n  <.meta meta={@meta} page_title={@page_title} />\n  <!-- other head elements -->\n \n```\n\nThe `meta` assign is expected to come from the `PhoenixSEOTools.SEO.build_meta/2` function.","ref":"PhoenixSEOTools.Components.Head.html#module-usage","title":"Usage - PhoenixSEOTools.Components.Head","type":"module"},{"doc":"Renders SEO-related meta tags, JSON-LD structured data, and link tags.","ref":"PhoenixSEOTools.Components.Head.html#meta/1","title":"PhoenixSEOTools.Components.Head.meta/1","type":"function"},{"doc":"* `page_title` - The title of the page (optional, will use `meta.page_title` if not provided)\n* `meta` - A map containing SEO metadata, typically coming from `PhoenixSEOTools.SEO.build_meta/2`\n  * `:page_title` - The title of the page\n  * `:metas` - A list of `PhoenixSEOTools.PageMeta` structs\n  * `:schemas` - A list of JSON-LD structured data maps\n  * `:links` - A list of `PhoenixSEOTools.PageLink` structs","ref":"PhoenixSEOTools.Components.Head.html#meta/1-attributes","title":"Attributes - PhoenixSEOTools.Components.Head.meta/1","type":"function"},{"doc":"```heex\n<.meta meta={@meta} page_title={@page_title} />\n```","ref":"PhoenixSEOTools.Components.Head.html#meta/1-examples","title":"Examples - PhoenixSEOTools.Components.Head.meta/1","type":"function"},{"doc":"* `page_title` (`:string`)\n* `meta` (`:map`) - Defaults to `%{}`.","ref":"PhoenixSEOTools.Components.Head.html#meta/1-attributes","title":"Attributes - PhoenixSEOTools.Components.Head.meta/1","type":"function"},{"doc":"A struct representing HTML link tags for SEO purposes.\n\nThis struct is used by the `PhoenixSEOTools.SEO` module to generate the necessary\nlink tags (like canonical URLs) for your pages and is consumed by the \n`PhoenixSEOTools.Components.Head` component.","ref":"PhoenixSEOTools.PageLink.html","title":"PhoenixSEOTools.PageLink","type":"module"},{"doc":"* `:rel` - The relationship of the link (e.g., \"canonical\")\n* `:href` - The URL that the link points to","ref":"PhoenixSEOTools.PageLink.html#module-fields","title":"Fields - PhoenixSEOTools.PageLink","type":"module"},{"doc":"A struct representing HTML meta tags for SEO purposes.\n\nThis struct is used by the `PhoenixSEOTools.SEO` module to generate the necessary\nmeta tags for your pages and is consumed by the `PhoenixSEOTools.Components.Head`\ncomponent.","ref":"PhoenixSEOTools.PageMeta.html","title":"PhoenixSEOTools.PageMeta","type":"module"},{"doc":"* `:name` - The name/property of the meta tag\n* `:content` - The content value of the meta tag","ref":"PhoenixSEOTools.PageMeta.html#module-fields","title":"Fields - PhoenixSEOTools.PageMeta","type":"module"},{"doc":"Core functionality for generating SEO-related metadata for your Phoenix application.\n\nThis module provides functions to generate various SEO elements:\n- Basic meta tags (title, description, image)\n- Open Graph tags for social media sharing\n- JSON-LD structured data (Organization, Website, Article, BreadcrumbList)\n- Canonical URLs","ref":"PhoenixSEOTools.SEO.html","title":"PhoenixSEOTools.SEO","type":"module"},{"doc":"To use this module, add the following to your application config:\n\n```elixir\nconfig :phoenix_seo_tools,\n  name: \"Your Site Name\",\n  url: \"https://yourdomain.com\",\n  logo_url: \"https://yourdomain.com/images/logo.png\",\n  description: \"Your site description\",\n  social_media_links: [\n    \"https://twitter.com/yourhandle\",\n    \"https://facebook.com/yourpage\"\n  ],\n  author: \"Your Name\"\n```","ref":"PhoenixSEOTools.SEO.html#module-configuration","title":"Configuration - PhoenixSEOTools.SEO","type":"module"},{"doc":"","ref":"PhoenixSEOTools.SEO.html#build_article_schema/2","title":"PhoenixSEOTools.SEO.build_article_schema/2","type":"function"},{"doc":"Builds metadata for a page and assigns it to the connection or socket.\n\nThis is the main function you'll use in your controllers or LiveViews to add SEO\nelements to your pages.","ref":"PhoenixSEOTools.SEO.html#build_meta/2","title":"PhoenixSEOTools.SEO.build_meta/2","type":"function"},{"doc":"* `conn_or_socket` - A Plug.Conn or Phoenix.LiveView.Socket\n* `options` - Keyword list of options:\n  * `:title` - The page title (required)\n  * `:description` - A description of the page (optional)\n  * `:image` - URL to an image representing the page (optional)\n  * `:breadcrumbs` - List of breadcrumb items (optional), each item should be a map with `:label` and `:to` keys\n  * `:article` - Article details for blog posts or articles (optional), should be a map with `:title`, `:description`, `:image`, `:inserted_at`, and `:slug` keys","ref":"PhoenixSEOTools.SEO.html#build_meta/2-parameters","title":"Parameters - PhoenixSEOTools.SEO.build_meta/2","type":"function"},{"doc":"* A conn or socket with the `:meta` assign containing all generated metadata","ref":"PhoenixSEOTools.SEO.html#build_meta/2-returns","title":"Returns - PhoenixSEOTools.SEO.build_meta/2","type":"function"},{"doc":"```elixir\n# In a controller:\nconn = PhoenixSEOTools.SEO.build_meta(conn, title: \"Welcome\", description: \"Our homepage\")\n\n# In a LiveView:\nsocket = PhoenixSEOTools.SEO.build_meta(socket, \n  title: \"Blog Post\",\n  description: \"An interesting article\",\n  image: \"https://example.com/images/post.jpg\",\n  breadcrumbs: [\n    %{label: \"Home\", to: \"/\"},\n    %{label: \"Blog\", to: \"/blog\"}\n  ],\n  article: %{\n    title: \"Blog Post\",\n    description: \"An interesting article\",\n    image: \"https://example.com/images/post.jpg\",\n    inserted_at: ~N[2023-01-01 12:00:00],\n    slug: \"blog-post\"\n  }\n)\n```","ref":"PhoenixSEOTools.SEO.html#build_meta/2-examples","title":"Examples - PhoenixSEOTools.SEO.build_meta/2","type":"function"},{"doc":"","ref":"PhoenixSEOTools.SEO.html#truncate/1","title":"PhoenixSEOTools.SEO.truncate/1","type":"function"},{"doc":"","ref":"PhoenixSEOTools.SEO.html#truncate/2","title":"PhoenixSEOTools.SEO.truncate/2","type":"function"},{"doc":"","ref":"PhoenixSEOTools.SEO.html#truncate/3","title":"PhoenixSEOTools.SEO.truncate/3","type":"function"},{"doc":"# PhoenixSEOTools\n\nPhoenixSEOTools is a lightweight Elixir library for Phoenix and Phoenix LiveView applications that helps you build SEO-optimized websites with minimal configuration. It generates and manages meta tags, Open Graph tags, JSON-LD schemas, and canonical links to improve your site's search engine visibility and social media presentation.","ref":"readme.html","title":"PhoenixSEOTools","type":"extras"},{"doc":"- Automatic generation of SEO meta tags (title, description, image)\n- Open Graph tags for better social media sharing\n- JSON-LD structured data for search engines (Organization, Website, Article, BreadcrumbList)\n- Canonical URL management\n- Simple integration with Phoenix and Phoenix LiveView\n- Customizable for any website","ref":"readme.html#features","title":"Features - PhoenixSEOTools","type":"extras"},{"doc":"Add `phoenix_seo_tools` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_seo_tools, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - PhoenixSEOTools","type":"extras"},{"doc":"Add required configuration to your application's config:\n\n```elixir\n# In config/config.exs\nconfig :phoenix_seo_tools,\n  name: \"My Site Name\",\n  url: \"https://yourdomain.com\",\n  logo_url: \"https://yourdomain.com/images/logo.png\",\n  description: \"My site description\",\n  social_media_links: [\n    \"https://twitter.com/yourhandle\",\n    \"https://facebook.com/yourpage\"\n  ],\n  author: \"My Name\"\n```","ref":"readme.html#configuration","title":"Configuration - PhoenixSEOTools","type":"extras"},{"doc":"","ref":"readme.html#usage","title":"Usage - PhoenixSEOTools","type":"extras"},{"doc":"```elixir\ndefmodule MyAppWeb.PageController do\n  use MyAppWeb, :controller\n  \n  def show(conn, %{\"slug\" => slug}) do\n    # Fetch your page data\n    page = Pages.get_by_slug!(slug)\n    \n    # Add SEO metadata\n    conn\n    |> PhoenixSEOTools.SEO.build_meta(\n      title: page.title,\n      description: page.description,\n      image: page.hero_url,\n      breadcrumbs: [\n        %{label: \"Home\", to: \"/\"},\n        %{label: \"Pages\", to: \"/pages\"},\n        %{label: page.title, to: \"/pages/#{page.slug}\"}\n      ]\n    )\n    |> render(:show, page: page)\n  end\nend\n```","ref":"readme.html#in-controllers","title":"In Controllers - PhoenixSEOTools","type":"extras"},{"doc":"```elixir\ndefmodule MyAppWeb.ArticleLive do\n  use MyAppWeb, :live_view\n  \n  def mount(%{\"slug\" => slug}, _session, socket) do\n    article = Articles.get_by_slug!(slug)\n    \n    # Add SEO metadata\n    socket = PhoenixSEOTools.SEO.build_meta(socket,\n      title: article.title,\n      description: article.summary,\n      image: article.cover_image_url,\n      article: %{\n        title: article.title,\n        description: article.summary,\n        image: article.cover_image_url,\n        inserted_at: article.published_at,\n        slug: article.slug\n      }\n    )\n    \n    {:ok, assign(socket, article: article)}\n  end\nend\n```","ref":"readme.html#in-liveviews","title":"In LiveViews - PhoenixSEOTools","type":"extras"},{"doc":"Add the meta component to your ` ` tag inside root layout:\n\n```elixir\n# In lib/your_app_web/components/layouts/root.html.heex\n \n  ...\n   \n  ...\n \n```","ref":"readme.html#in-your-layout","title":"In your layout - PhoenixSEOTools","type":"extras"},{"doc":"Complete documentation is available at [https://hexdocs.pm/phoenix_seo_tools](https://hexdocs.pm/phoenix_seo_tools).","ref":"readme.html#documentation","title":"Documentation - PhoenixSEOTools","type":"extras"},{"doc":"MIT License. See LICENSE file for details.","ref":"readme.html#license","title":"License - PhoenixSEOTools","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.3"},"proglang":"elixir"}